[![forthebadge](http://forthebadge.com/images/badges/built-with-love.svg)](https://www.gobolinux.org/)
[![forthebadge](http://forthebadge.com/images/badges/made-with-ruby.svg)](https://www.ruby-lang.org/en/)
[![Gem Version](https://badge.fury.io/rb/chemistry_paradise.svg)](https://badge.fury.io/rb/chemistry_paradise)

## Introduction

This project bundles together some commonly used methods and classes
related to **chemistry**.

## The individual classes in this project

To the individual classes:

- **CalculateAtomicMass** will calculate the mass.

Argument to this class should be something such as <b>C16H12N2</b>.

So:

    ChemistryParadise::CalculateAtomicMass.new('C16H12N2')
    ChemistryParadise::CalculateAtomicMass.new('CH3Cl')
    ChemistryParadise::CalculateAtomicMass.new('CH₃Cl') # ← This variant also works since as of December 2019.
    ChemistryParadise::CalculateAtomicMass.new('CO₂')   # ← As does this, too, since as of December 2019.

If you need **english output**, look at the entry default language
to use within the project, in this file.

- **ChemistryParadise::Orbitals** will simply show how many
electrons fit into an orbital.

- The class **ChemistryParadise::ShowElectronConfiguration**
will report the electron configuration for the given element.

For example, if you pass 'Fe' as element (iron), then the
class will report something like this:

    Found element Fe. It has 26 electrons.
    [Ar] 4s2 3d6

Specific example in pure ruby:

    require 'chemistry_paradise'
    ChemistryParadise::ShowElectronConfiguration.new('Fe')

Note that this may not work as well for heavy atoms, but for
the more common ~smaller atoms, it should work fine.

## Default language to use within the project

The project initially showed output mostly in the german language.

However had - most people may prefer the english language, so a
switch exists that allows you to toggle the behaviour of the
ChemistryParadise project, in regards to the language at hand.

If you wish to **use the english language**, you can use the following
method call:

    ChemistryParadise.do_use_english

Also, the Base class allows one to switch between the english
and the german language.

Either way, past this point, if you invoke **class CalculateAtomicMass**,
it will then report the result in english. Internally the
module-method instance variable called <b>@language</b> will
keep track of the language at hand.

See also the test/ subdirectory to look at this in action.

## German names of atoms/elements

In the german language, we can find names such as <b>Quecksilber</b>
for the element <b>Hg</b> (mercury, aka <b>hydrargyrum</b>).

The file <b>german_names_of_elements_to_element_symbol.rb</b>
handles this conversion, but you can also query the translated
symbol-name from the commandliny, by using a pseudo-regex such
as:

    chemistry_paradise /Quecksilber/

So in other words, the german name of the element at hand is
to be put between the two **/** characters.

The default pseudo-regex may change one day, in which case
the change would be properly documented here as well.

## class ChemistryParadise::ShowElectronNegativityOfThisElement

<b>class ChemistryParadise::ShowElectronNegativityOfThisElement</b>
can be used to show, on the commandline, the electron negativity
of the given elements.

So for example, if you'd want to know to know the electron negativity
of Fluor and Iron, you'd pass in this:

    ChemistryParadise::ShowElectronNegativityOfThisElement.new(['F','Fe'])

From the commandline, if you aliased towards the .rb file, simply pass
in F and Fe, without any ' quotes.

If you want another accessor, also from the commandline, then do:

    chemistry_paradise --electronegativity-of=F/Fe

In that case, <b>/</b> acts as the separator between several elements.

<b>Always input the element symbol, NOT the long name of the
element.</b>

See **wikipedia** for a complete list of elements.

If you intent to use this part of the chemistry_paradise project
to predict whether two elements form an ionic bond, as a rule of
thumb, the difference should be at the very least <b>1.5</b> between
the two elements; ideally <b>1.8</b>. Past that point it can
be concluded, that two different elements with such a large
discrepancy in their electron negativity values, would form 
<b>ionic bonds</b> (if they would bind to one another in the
first place, that is).

## Showing the individual steps

If you wish to display the molecular mass of some compound, on
the commandline, and would also like to display the individual
steps done, you can use the following commandline flag:

    mmasse CaCO3 --show-steps

Note that this will probably be extended in the future, so
that this also works a bit like a **debug-flag**. The idea
here is to be able to verify what is going on in a simple
manner, rather than to merely rely on the output **assumed**
to be correct.

## Disclaimer

Keep in mind that this is merely a hobby project, not a "fully
fledged professional" suite of code.

I use it primarily to help me in little things, such as querying
the electron configuration of an atom on the commandline, or
calculating the molar mass of a compound. I could do the latter
manually but computers are a lot faster and a lot less work
than manual calculations - and more reliable, too.

As this is not professional chemistry-software, please do not
expect that this project could ever really help calculating
the Schroedinger equation or anything similar to that.


## Contact information

If you have specific suggestions to make this gem more
useful for others, please drop me an email at:

    shevegen@gmail.com

(Please keep in mind that responding to emails may take
a while depending on the amount of work I may have at
that moment in time due to reallife.)

Thank you.
